cmd_commands=[
"arp",
"assoc",
"attrib",
"auditpol",
"bcdboot",
"bcdedit",
"bitsadmin",
"BREAK",
"cacls",
"call",
"cd",
"certreq",
"certutil",
"change",
"changepk",
"chcp",
"chdir",
"chkdsk",
"chkntfs",
"choice",
"cipher",
"cleanmgr",
"clip",
"cls",
"cmd"
"cmdkey",
"color",
"comp",
"compact",
"convert",
"copy",
"curl",
"date",
"defrag",
"DEL",
"dir",
"diskpart",
"dism",
"displayswitch",
"doskey",
"driverquery",
"dsregcmd",
"echo",
"endlocal",
"erase",
"esentutl",
"eventcreate",
"exit",
"expand",
"explorer",
"fc",
"find",
"findstr",
"fltmc",
"FOR",
"forfiles",
"format",
"fsutil",
"ftp",
"ftype",
"getmac",
"goto",
"gpresult",
"gpupdate",
"help",
"hostname",
"icacls",
"iexpress",
"IF",
"ipconfig",
"klist",
"label",
"lodctr",
"logman",
"logoff",
"makecab",
"manage_bde",
"mbr2gpt",
"md",
"mkdir",
"mklink",
"mode",
"more",
"mountvol",
"move",
"moveuser",
"msg",
"msiexec",
"msinfo32",
"mstsc",
"nbtstat",
"net",
"netsh",
"netstat",
"nltest",
"nslookup",
"openfiles",
"path",
"pathping",
"pause",
"ping",
"pktmon",
"pnputil",
"popd",
"powercfg",
"PRINT",
"prompt",
"pushd",
"qappsrv",
"qprocess",
"quser",
"qwinsta",
"rasdial",
"rasphone",
"rd",
"reagentc",
"recover",
"reg",
"regedit",
"regini",
"regsvr32",
"ren",
"replace",
"reset",
"rmdir",
"rmtshare",
"robocopy",
"route",
"runas",
"rundll32",
"sc",
"schtasks",
"scriptrunner",
"set",
"setlocal",
"setspn",
"setx",
"sfc",
"shift",
"shutdown",
"sleep",
"slmgr",
"sort",
"ssh",
"start",
"subst",
"sxstrace",
"systeminfo",
"takeown",
"tar",
"taskkill",
"tasklist",
"time",
"timeout",
"title",
"tracert",
"tree",
"tsdiscon",
"tskill",
"type",
"typeperf",
"tzutil",
"ver",
"verify",
"vol",
"vssadmin",
"w32tm",
"waitfor",
"wbadmin",
"wecutil",
"wevtutil",
"where",
"whoami",
"windiff",
"winget",
"winmgmt",
"winrm",
"winrs",
"wmic",
"wpr",
"wt",
"wuauclt",
"wusa",
"xcopy"
]