archivos = [
"arp.py",
"assoc.py",
"attrib.py",
"auditpol.py",
"bcdboot.py",
"bcdedit.py",
"bitsadmin.py",
"BREAK.py",
"cacls.py",
"call.py",
"cd.py",
"certreq.py",
"certutil.py",
"change.py",
"changepk.py",
"chcp.py",
"chdir.py",
"chkdsk.py",
"chkntfs.py",
"choice.py",
"cipher.py",
"cleanmgr.py",
"clip.py",
"cls.py",
"cmdkey.py",
"color.py",
"comp.py",
"compact.py",
"convert.py",
"copy.py",
"curl.py",
"date.py",
"defrag.py",
"DEL.py",
"dir.py",
"diskpart.py",
"dism.py",
"displayswitch.py",
"doskey.py",
"driverquery.py",
"dsregcmd.py",
"echo.py",
"endlocal.py",
"erase.py",
"esentutl.py",
"eventcreate.py",
"exit.py",
"expand.py",
"explorer.py",
"fc.py",
"find.py",
"findstr.py",
"fltmc.py",
"FOR.py",
"forfiles.py",
"format.py",
"fsutil.py",
"ftp.py",
"ftype.py",
"getmac.py",
"goto.py",
"gpresult.py",
"gpupdate.py",
"help.py",
"hostname.py",
"icacls.py",
"iexpress.py",
"IF.py",
"ipconfig.py",
"klist.py",
"label.py",
"lodctr.py",
"logman.py",
"logoff.py",
"makecab.py",
"manage_bde.py",
"mbr2gpt.py",
"md.py",
"mkdir.py",
"mklink.py",
"mode.py",
"more.py",
"mountvol.py",
"move.py",
"moveuser.py",
"msg.py",
"msiexec.py",
"msinfo32.py",
"mstsc.py",
"nbtstat.py",
"net.py",
"netsh.py",
"netstat.py",
"nltest.py",
"nslookup.py",
"openfiles.py",
"path.py",
"pathping.py",
"pause.py",
"ping.py",
"pktmon.py",
"pnputil.py",
"popd.py",
"powercfg.py",
"PRINT.py",
"prompt.py",
"pushd.py",
"qappsrv.py",
"qprocess.py",
"quser.py",
"qwinsta.py",
"rasdial.py",
"rasphone.py",
"rd.py",
"reagentc.py",
"recover.py",
"reg.py",
"regedit.py",
"regini.py",
"regsvr32.py",
"ren.py",
"replace.py",
"reset.py",
"rmdir.py",
"rmtshare.py",
"robocopy.py",
"route.py",
"runas.py",
"rundll32.py",
"sc.py",
"schtasks.py",
"scriptrunner.py",
"set.py",
"setlocal.py",
"setspn.py",
"setx.py",
"sfc.py",
"shift.py",
"shutdown.py",
"sleep.py",
"slmgr.py",
"sort.py",
"ssh.py",
"start.py",
"subst.py",
"sxstrace.py",
"systeminfo.py",
"takeown.py",
"tar.py",
"taskkill.py",
"tasklist.py",
"time.py",
"timeout.py",
"title.py",
"tracert.py",
"tree.py",
"tsdiscon.py",
"tskill.py",
"type.py",
"typeperf.py",
"tzutil.py",
"ver.py",
"verify.py",
"vol.py",
"vssadmin.py",
"w32tm.py",
"waitfor.py",
"wbadmin.py",
"wecutil.py",
"wevtutil.py",
"where.py",
"whoami.py",
"windiff.py",
"winget.py",
"winmgmt.py",
"winrm.py",
"winrs.py",
"wmic.py",
"wpr.py",
"wt.py",
"wuauclt.py",
"wusa.py",
"xcopy.py"
]


# Crear un nuevo archivo llamado "mi_archivo.txt" y escribir en él

for archivo in archivos:
    archivo_sin_extencion = archivo.split(".",1)
    content = f"""
from ..bin.cmd import cmd

def {archivo_sin_extencion}(arguments=None):
    command = [
        "{archivo_sin_extencion}",
        arguments
    ]
    return cmd(command)
    """
    with open(archivo, "w") as file:
        file.write(content)